# ResultResponseAlgorithmSchema


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**status** | **str** |  | [optional] [default to 'success']
**result** | [**AlgorithmSchema**](AlgorithmSchema.md) |  | 

## Example

```python
from haplohub.models.result_response_algorithm_schema import ResultResponseAlgorithmSchema

# TODO update the JSON string below
json = "{}"
# create an instance of ResultResponseAlgorithmSchema from a JSON string
result_response_algorithm_schema_instance = ResultResponseAlgorithmSchema.from_json(json)
# print the JSON string representation of the object
print ResultResponseAlgorithmSchema.to_json()

# convert the object into a dict
result_response_algorithm_schema_dict = result_response_algorithm_schema_instance.to_dict()
# create an instance of ResultResponseAlgorithmSchema from a dict
result_response_algorithm_schema_from_dict = ResultResponseAlgorithmSchema.from_dict(result_response_algorithm_schema_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


